pub struct AdvancedPwm<'d, T: Instance> { /* private fields */ }Expand description
Struct used to divide a high resolution timer into multiple channels
Implementations
Sourceimpl<'d, T: Instance> AdvancedPwm<'d, T>
impl<'d, T: Instance> AdvancedPwm<'d, T>
Sourcepub fn new(
tim: Peri<'d, T>,
_cha: Option<HRPin<'d, T, ChA>>,
_chb: Option<HRPin<'d, T, ChB>>,
_chc: Option<HRPin<'d, T, ChC>>,
_chd: Option<HRPin<'d, T, ChD>>,
_che: Option<HRPin<'d, T, ChE>>,
) -> Self
pub fn new( tim: Peri<'d, T>, _cha: Option<HRPin<'d, T, ChA>>, _chb: Option<HRPin<'d, T, ChB>>, _chc: Option<HRPin<'d, T, ChC>>, _chd: Option<HRPin<'d, T, ChD>>, _che: Option<HRPin<'d, T, ChE>>, ) -> Self
Create a new HRTIM driver.
This splits the HRTIM into its constituent parts, which you can then use individually.